# Define python_sitearch macro
%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}

# we don't want to provide private python extension libs
%{?filter_setup:
%filter_provides_in %{python_sitearch}/.*\.so$ 
%filter_setup
}

%ifnarch ppc ppc64
# Use libint by default
%global _libint 1 
%else
# Don't use libint on ppc architectures
%global _libint 0
%endif

Name:		PyQuante
Version:	1.6.5
Release:	1%{?dist}
Summary:	Python Quantum Chemistry
Group:		Applications/Engineering
License:	BSD
URL:		http://pyquante.sourceforge.net/
Source0:	http://downloads.sourceforge.net/pyquante/%{name}-%{version}.tar.gz
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

# Link against system libint
Patch0:		PyQuante-libint.patch

BuildRequires:	python-devel
BuildRequires:	python-setuptools
BuildRequires:	numpy
%if %{_libint}
BuildRequires:	libint-devel
%endif

Requires:	numpy
Requires:	openbabel


%description
PyQuante is an open-source suite of programs for developing quantum chemistry
methods. The program is written in the Python programming language, but has
many "rate-determining" modules also written in C for speed. The resulting
code, though not as fast as Jaguar, NWChem, Gaussian, or GAMESS, is much
easier to understand and modify. The goal of this software is not necessarily
to provide a working quantum chemistry program (although it will hopefully do
that), but rather to provide a well-engineered set of tools so that scientists
can construct their own quantum chemistry programs without going through the
tedium of having to write every low-level routine.

You might want to install PyQuante-libint as well, which speeds up the
calculation of two-electron integrals.

%if %{_libint}
%package libint
Summary:	Libint integration to PyQuante
Group:		Applications/Engineering
Requires:	%{name} = %{version}-%{release}
License:	GPLv2+
# Require exact release used to build the package
Requires:	libint(api)%{?_isa} = %{_libint_apiversion}

%description libint
This package contains integration of PyQuante with the libint library
for computing two-electron integrals. It is much faster than the
normal routines in PyQuante.
%endif

%prep
%setup -q
%patch0 -p1 -b .libint
# Get rid of spurious attributes
chmod 644 LICENSE Src/{cints.c,chgp.c,crys.c,crys.h}
# Get rid of spurious files
rm -rf Tests/.gdb_history

%build
%if %{_libint}
python -c 'import setuptools; execfile("setup.py")' build --enable-libint
%else
python -c 'import setuptools; execfile("setup.py")' build
%endif

%install
rm -rf %{buildroot}
python -c 'import setuptools; execfile("setup.py")' install --skip-build --root %{buildroot}

%clean
rm -rf %{buildroot}

%check
# Make tests able to find PyQuante
libdir=`ls build/|grep lib`
export PYTHONPATH=`pwd`/build/$libdir
# Run tests
cd Tests
./runalltests.py 

%files
%defattr(-,root,root,-)
%doc LICENSE README
%{python_sitearch}/%{name}/
%{python_sitearch}/%{name}-%{version}-py*.egg-info
%if %{_libint}
# libint library goes into a different package due to different licensing
%exclude %{python_sitearch}/%{name}/clibint.so
%endif

%if %{_libint}
%files libint
%defattr(-,root,root,-)
%{python_sitearch}/%{name}/clibint.so
%endif

%changelog
* Mon Oct 27 2014 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.6.5-1
- Update to 1.6.5.

* Thu Oct 16 2014 Pierre-Yves Chibon <pingou@pingoured.fr> - 1.6.4-13
- rebuilt to fix broken deps

* Tue Sep 09 2014 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.6.4-12
- Switch to requiring libint api version.

* Fri Aug 15 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.4-11.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Tue Jul 01 2014 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.6.4-10.1
- Rebuild due to rebuilt libint.

* Fri Jun 06 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.4-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Mon Mar 10 2014 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.6.4-9
- Rebuild against updated libint.

* Sun Dec 22 2013 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.6.4-8
- Rebuild due to changed libint.

* Fri Aug 02 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.4-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.4-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Jul 25 2012 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.6.4-5
- Rebuild due to changed libint.

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.4-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Jan 12 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Jan 22 2011 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.6.4-1
- Update to 1.6.4.
- Drop tests from package, since they are run upon build.

* Thu Dec 02 2010 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.6.3-7.174svn
- Rebuild against libint, which was recompiled to support basis sets of
  larger angular momentum.

* Wed Dec 01 2010 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.6.3-6.174svn
- Added Requires: openbabel.
- Split libint library in a separate package due to the resulting binary
  being GPLv2+ licensed.

* Wed Nov 03 2010 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.6.3-5.174svn
- Switch to using an SVN snapshot.
- Build against libint.
- Run tests.

* Wed Jul 21 2010 David Malcolm <dmalcolm@redhat.com> - 1.6.3-4
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Thu Dec 17 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.6.3-3
- Fix FTBFS on Fedora 13.

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.6.3-1
- Update to 1.6.3 that fixes the rest of the rpmlint errors.

* Wed Feb 25 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.6.2-1
- Fix source URL.
- Update to 1.6.2 that removes the shebangs and removes the use of the with 
keyword.

* Tue Feb 24 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.6.1-5
- Add tests to %%{_datadir}/%%{name}.

* Tue Feb 24 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.6.1-4
- Review fixes.

* Fri Nov 21 2008 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.6.1-3
- Fixed license tag.

* Thu Nov 13 2008 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.6.1-2
- Initial review fixes. 

* Sun Oct 26 2008 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.6.1-1
- First release.
